// MyButton.cpp : Implementation of CMyButton

#include "stdafx.h"
#include "MyButton.h"


// CMyButton

void STDMETHODCALLTYPE CMyButton::OnDocumentComplete(IDispatch *pDisp, VARIANT *pvarURL) {
    HRESULT hr = S_OK;

    // Query for the IWebBrowser2 interface.
    CComQIPtr<IWebBrowser2> spTempWebBrowser = pDisp;

    // Is this event associated with the top-level browser?
    if (spTempWebBrowser && m_spWebBrowser &&
        m_spWebBrowser.IsEqualObject(spTempWebBrowser)) {
        
        // Get the current document object from browser...
        CComPtr<IDispatch> spDispDoc;
        hr = m_spWebBrowser->get_Document(&spDispDoc);
        if (SUCCEEDED(hr)) {
            
            // ...and query for an HTML document.
            CComQIPtr<IHTMLDocument2> spHTMLDoc = spDispDoc;
            if (spHTMLDoc != NULL) {

                // Finally, remove the images.
                RemoveImages(spHTMLDoc);
                
            }
        }
    }
}

void CMyButton::RemoveImages(IHTMLDocument2* pDocument) {
    CComPtr<IHTMLElementCollection> spImages;

    // Get the collection of images from the DOM.
    HRESULT hr = pDocument->get_images(&spImages);
    if (hr == S_OK && spImages != NULL) {
        // Get the number of images in the collection.
        long cImages = 0;
        hr = spImages->get_length(&cImages);
        if (hr == S_OK && cImages > 0) {

            for (int i = 0; i < cImages; i++) {
                CComVariant svarItemIndex(i);
                CComVariant svarEmpty;
                CComPtr<IDispatch> spdispImage;

                // Get the image out of the collection by index.
                hr = spImages->item(svarItemIndex, svarEmpty, &spdispImage);
                if (hr == S_OK && spdispImage != NULL) {
                    // First, query for the generic HTML element interface...
                    CComQIPtr<IHTMLElement> spElement = spdispImage;

                    if (spElement) {
                        // ...then ask for the style interface.
                        CComPtr<IHTMLStyle> spStyle;
                        hr = spElement->get_style(&spStyle);

                        // Set display="none" to hide the image.
                        if (hr == S_OK && spStyle != NULL) {
                            static const CComBSTR sbstrNone(L"none");
                            spStyle->put_display(sbstrNone);
                        }
                    }
                }
            }
        }
    }
}

STDMETHODIMP CMyButton::SetSite(IUnknown *pUnkSite) {
    if (pUnkSite != NULL) {
        // Cache the pointer to IWebBrowser2
        CComQIPtr<IServiceProvider> sp = pUnkSite;
        HRESULT hr = sp->QueryService(IID_IWebBrowserApp,  IID_IWebBrowser2, (void**)&m_spWebBrowser);
        hr = sp->QueryInterface(IID_IOleCommandTarget, (void**)&m_spTarget);
        if (SUCCEEDED(hr)) {
            
            // Register to sink events from DWebBrowserEvents2.
            hr = IDispEventImpl::DispEventAdvise(m_spWebBrowser);
            if (SUCCEEDED(hr)) {
                m_fAdvised = TRUE;
            }
        }
    } else {
        // Unregister event sink.
        if (m_fAdvised) {
            IDispEventImpl::DispEventUnadvise(m_spWebBrowser);
            m_fAdvised = FALSE;
        }

        // Release pointer
        m_spWebBrowser.Release();
        m_spTarget.Release();
    }

    // Return base implementation
    return IObjectWithSiteImpl<CMyButton>::SetSite(pUnkSite);
}

STDMETHODIMP CMyButton::Exec(const GUID *pguidCmdGroup, DWORD nCmdID,  DWORD nCmdExecOpt, VARIANTARG *pvaIn, VARIANTARG *pvaOut) {
    if (m_spWebBrowser != NULL) {
        return S_OK;
    } else {
        MessageBox(NULL, _T("No Web browser pointer"), _T("Oops"), 0);
        return E_ABORT;
    }
}

STDMETHODIMP CMyButton::QueryStatus(const GUID *pguidCmdGroup, ULONG cCmds, OLECMD prgCmds[], OLECMDTEXT *pCmdText) {

    HRESULT hr = OLECMDERR_E_UNKNOWNGROUP;
    if (pguidCmdGroup && IsEqualGUID(*pguidCmdGroup, CLSID_ToolbarExtButtons)) {
        for (ULONG i = 0; i < cCmds; i++) {
            if (m_spWebBrowser) {
                // By default, we'll support all commands
                prgCmds[i].cmdf = OLECMDF_ENABLED | OLECMDF_SUPPORTED;
            } else {
                // If we wanted to latch the button down, we could do this:
                prgCmds[i].cmdf |= OLECMDF_LATCHED;
            }
        }
        hr = S_OK;
    }

    return hr;

}
